"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractPrivyProvider = void 0;
const react_auth_1 = require("@privy-io/react-auth");
const react_query_1 = require("@tanstack/react-query");
const react_1 = require("react");
const chains_1 = require("viem/chains");
const wagmi_1 = require("wagmi");
const constants_js_1 = require("../constants.js");
const injectWagmiConnector_js_1 = require("./injectWagmiConnector.js");
const privyAppLoginMethod = `privy:${constants_js_1.AGW_APP_ID}`;
const AbstractPrivyProvider = ({ testnet = false, transport, ...props }) => {
    const chain = testnet ? chains_1.abstractTestnet : chains_1.abstractTestnet;
    const wagmiConfig = (0, wagmi_1.createConfig)({
        chains: [chain],
        ssr: true,
        connectors: [],
        transports: {
            [chain.id]: transport ?? (0, wagmi_1.http)(),
        },
        multiInjectedProviderDiscovery: false,
    });
    const queryClient = new react_query_1.QueryClient();
    if (!props.config) {
        props.config = {
            loginMethodsAndOrder: {
                primary: [privyAppLoginMethod],
            },
        };
    }
    else if (!props.config.loginMethodsAndOrder) {
        props.config.loginMethodsAndOrder = {
            primary: [privyAppLoginMethod],
        };
    }
    else {
        if (!(props.config.loginMethodsAndOrder.primary.includes(privyAppLoginMethod) ||
            (props.config.loginMethodsAndOrder.overflow &&
                props.config.loginMethodsAndOrder.overflow.includes(privyAppLoginMethod)))) {
            props.config.loginMethodsAndOrder.primary = [
                privyAppLoginMethod,
                ...props.config.loginMethodsAndOrder.primary,
            ];
        }
    }
    return (react_1.default.createElement(react_auth_1.PrivyProvider, { ...props },
        react_1.default.createElement(wagmi_1.WagmiProvider, { config: wagmiConfig },
            react_1.default.createElement(react_query_1.QueryClientProvider, { client: queryClient },
                react_1.default.createElement(injectWagmiConnector_js_1.InjectWagmiConnector, { chain: chain }, props.children)))));
};
exports.AbstractPrivyProvider = AbstractPrivyProvider;
//# sourceMappingURL=abstractPrivyProvider.js.map