import { PrivyProvider, } from '@privy-io/react-auth';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import React from 'react';
import {} from 'viem';
import { abstractTestnet } from 'viem/chains';
import { createConfig, http, WagmiProvider } from 'wagmi';
import { AGW_APP_ID } from '../constants.js';
import { InjectWagmiConnector } from './injectWagmiConnector.js';
const privyAppLoginMethod = `privy:${AGW_APP_ID}`;
export const AbstractPrivyProvider = ({ testnet = false, transport, ...props }) => {
    const chain = testnet ? abstractTestnet : abstractTestnet;
    const wagmiConfig = createConfig({
        chains: [chain],
        ssr: true,
        connectors: [],
        transports: {
            [chain.id]: transport ?? http(),
        },
        multiInjectedProviderDiscovery: false,
    });
    const queryClient = new QueryClient();
    if (!props.config) {
        props.config = {
            loginMethodsAndOrder: {
                primary: [privyAppLoginMethod],
            },
        };
    }
    else if (!props.config.loginMethodsAndOrder) {
        props.config.loginMethodsAndOrder = {
            primary: [privyAppLoginMethod],
        };
    }
    else {
        if (
        // check if the privy app login method is in the primary or overflow list
        !(props.config.loginMethodsAndOrder.primary.includes(privyAppLoginMethod) ||
            (props.config.loginMethodsAndOrder.overflow &&
                props.config.loginMethodsAndOrder.overflow.includes(privyAppLoginMethod)))) {
            props.config.loginMethodsAndOrder.primary = [
                privyAppLoginMethod,
                ...props.config.loginMethodsAndOrder.primary,
            ];
        }
    }
    return (React.createElement(PrivyProvider, { ...props },
        React.createElement(WagmiProvider, { config: wagmiConfig },
            React.createElement(QueryClientProvider, { client: queryClient },
                React.createElement(InjectWagmiConnector, { chain: chain }, props.children)))));
};
//# sourceMappingURL=abstractPrivyProvider.js.map